@@ -25,6 +25,8 @@ pub enum ChatReportReason {
   Copyright(ChatReportReasonCopyright),
   /// A custom reason provided by the user
   Custom(ChatReportReasonCustom),
+  /// The chat represents a fake account
+  Fake(ChatReportReasonFake),
   /// The chat contains pornographic messages
   Pornography(ChatReportReasonPornography),
   /// The chat contains spam messages
@@ -48,6 +50,7 @@ impl<'de> Deserialize<'de> for ChatReportReason {
       (chatReportReasonChildAbuse, ChildAbuse);
       (chatReportReasonCopyright, Copyright);
       (chatReportReasonCustom, Custom);
+      (chatReportReasonFake, Fake);
       (chatReportReasonPornography, Pornography);
       (chatReportReasonSpam, Spam);
       (chatReportReasonUnrelatedLocation, UnrelatedLocation);
@@ -63,6 +66,7 @@ impl RObject for ChatReportReason {
       ChatReportReason::ChildAbuse(t) => t.td_name(),
       ChatReportReason::Copyright(t) => t.td_name(),
       ChatReportReason::Custom(t) => t.td_name(),
+      ChatReportReason::Fake(t) => t.td_name(),
       ChatReportReason::Pornography(t) => t.td_name(),
       ChatReportReason::Spam(t) => t.td_name(),
       ChatReportReason::UnrelatedLocation(t) => t.td_name(),
@@ -76,6 +80,7 @@ impl RObject for ChatReportReason {
       ChatReportReason::ChildAbuse(t) => t.extra(),
       ChatReportReason::Copyright(t) => t.extra(),
       ChatReportReason::Custom(t) => t.extra(),
+      ChatReportReason::Fake(t) => t.extra(),
       ChatReportReason::Pornography(t) => t.extra(),
       ChatReportReason::Spam(t) => t.extra(),
       ChatReportReason::UnrelatedLocation(t) => t.extra(),
@@ -94,6 +99,7 @@ impl ChatReportReason {
   pub fn is_child_abuse(&self) -> bool { if let ChatReportReason::ChildAbuse(_) = self { true } else { false } }
   pub fn is_copyright(&self) -> bool { if let ChatReportReason::Copyright(_) = self { true } else { false } }
   pub fn is_custom(&self) -> bool { if let ChatReportReason::Custom(_) = self { true } else { false } }
+  pub fn is_fake(&self) -> bool { if let ChatReportReason::Fake(_) = self { true } else { false } }
   pub fn is_pornography(&self) -> bool { if let ChatReportReason::Pornography(_) = self { true } else { false } }
   pub fn is_spam(&self) -> bool { if let ChatReportReason::Spam(_) = self { true } else { false } }
   pub fn is_unrelated_location(&self) -> bool { if let ChatReportReason::UnrelatedLocation(_) = self { true } else { false } }
@@ -102,6 +108,7 @@ impl ChatReportReason {
   pub fn on_child_abuse<F: FnOnce(&ChatReportReasonChildAbuse)>(&self, fnc: F) -> &Self { if let ChatReportReason::ChildAbuse(t) = self { fnc(t) }; self }
   pub fn on_copyright<F: FnOnce(&ChatReportReasonCopyright)>(&self, fnc: F) -> &Self { if let ChatReportReason::Copyright(t) = self { fnc(t) }; self }
   pub fn on_custom<F: FnOnce(&ChatReportReasonCustom)>(&self, fnc: F) -> &Self { if let ChatReportReason::Custom(t) = self { fnc(t) }; self }
+  pub fn on_fake<F: FnOnce(&ChatReportReasonFake)>(&self, fnc: F) -> &Self { if let ChatReportReason::Fake(t) = self { fnc(t) }; self }
   pub fn on_pornography<F: FnOnce(&ChatReportReasonPornography)>(&self, fnc: F) -> &Self { if let ChatReportReason::Pornography(t) = self { fnc(t) }; self }
   pub fn on_spam<F: FnOnce(&ChatReportReasonSpam)>(&self, fnc: F) -> &Self { if let ChatReportReason::Spam(t) = self { fnc(t) }; self }
   pub fn on_unrelated_location<F: FnOnce(&ChatReportReasonUnrelatedLocation)>(&self, fnc: F) -> &Self { if let ChatReportReason::UnrelatedLocation(t) = self { fnc(t) }; self }
@@ -110,6 +117,7 @@ impl ChatReportReason {
   pub fn as_child_abuse(&self) -> Option<&ChatReportReasonChildAbuse> { if let ChatReportReason::ChildAbuse(t) = self { return Some(t) } None }
   pub fn as_copyright(&self) -> Option<&ChatReportReasonCopyright> { if let ChatReportReason::Copyright(t) = self { return Some(t) } None }
   pub fn as_custom(&self) -> Option<&ChatReportReasonCustom> { if let ChatReportReason::Custom(t) = self { return Some(t) } None }
+  pub fn as_fake(&self) -> Option<&ChatReportReasonFake> { if let ChatReportReason::Fake(t) = self { return Some(t) } None }
   pub fn as_pornography(&self) -> Option<&ChatReportReasonPornography> { if let ChatReportReason::Pornography(t) = self { return Some(t) } None }
   pub fn as_spam(&self) -> Option<&ChatReportReasonSpam> { if let ChatReportReason::Spam(t) = self { return Some(t) } None }
   pub fn as_unrelated_location(&self) -> Option<&ChatReportReasonUnrelatedLocation> { if let ChatReportReason::UnrelatedLocation(t) = self { return Some(t) } None }
@@ -123,6 +131,8 @@ impl ChatReportReason {
 
   pub fn custom<T: AsRef<ChatReportReasonCustom>>(t: T) -> Self { ChatReportReason::Custom(t.as_ref().clone()) }
 
+  pub fn fake<T: AsRef<ChatReportReasonFake>>(t: T) -> Self { ChatReportReason::Fake(t.as_ref().clone()) }
+
   pub fn pornography<T: AsRef<ChatReportReasonPornography>>(t: T) -> Self { ChatReportReason::Pornography(t.as_ref().clone()) }
 
   pub fn spam<T: AsRef<ChatReportReasonSpam>>(t: T) -> Self { ChatReportReason::Spam(t.as_ref().clone()) }
@@ -268,8 +278,6 @@ pub struct ChatReportReasonCustom {
   #[doc(hidden)]
   #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
   extra: Option<String>,
-  /// Report text
-  text: String,
   
 }
 
@@ -293,8 +301,6 @@ impl ChatReportReasonCustom {
     RTDChatReportReasonCustomBuilder { inner }
   }
 
-  pub fn text(&self) -> &String { &self.text }
-
 }
 
 #[doc(hidden)]
@@ -305,12 +311,6 @@ pub struct RTDChatReportReasonCustomBuilder {
 impl RTDChatReportReasonCustomBuilder {
   pub fn build(&self) -> ChatReportReasonCustom { self.inner.clone() }
 
-   
-  pub fn text<T: AsRef<str>>(&mut self, text: T) -> &mut Self {
-    self.inner.text = text.as_ref().to_string();
-    self
-  }
-
 }
 
 impl AsRef<ChatReportReasonCustom> for ChatReportReasonCustom {
@@ -327,6 +327,64 @@ impl AsRef<ChatReportReasonCustom> for RTDChatReportReasonCustomBuilder {
 
 
 
+/// The chat represents a fake account
+#[derive(Debug, Clone, Default, Serialize, Deserialize)]
+pub struct ChatReportReasonFake {
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@type", deserialize = "@type"))]
+  td_name: String,
+  #[doc(hidden)]
+  #[serde(rename(serialize = "@extra", deserialize = "@extra"))]
+  extra: Option<String>,
+  
+}
+
+impl RObject for ChatReportReasonFake {
+  #[doc(hidden)] fn td_name(&self) -> &'static str { "chatReportReasonFake" }
+  #[doc(hidden)] fn extra(&self) -> Option<String> { self.extra.clone() }
+  fn to_json(&self) -> RTDResult<String> { Ok(serde_json::to_string(self)?) }
+}
+
+
+impl TDChatReportReason for ChatReportReasonFake {}
+
+
+
+impl ChatReportReasonFake {
+  pub fn from_json<S: AsRef<str>>(json: S) -> RTDResult<Self> { Ok(serde_json::from_str(json.as_ref())?) }
+  pub fn builder() -> RTDChatReportReasonFakeBuilder {
+    let mut inner = ChatReportReasonFake::default();
+    inner.td_name = "chatReportReasonFake".to_string();
+    inner.extra = Some(Uuid::new_v4().to_string());
+    RTDChatReportReasonFakeBuilder { inner }
+  }
+
+}
+
+#[doc(hidden)]
+pub struct RTDChatReportReasonFakeBuilder {
+  inner: ChatReportReasonFake
+}
+
+impl RTDChatReportReasonFakeBuilder {
+  pub fn build(&self) -> ChatReportReasonFake { self.inner.clone() }
+
+}
+
+impl AsRef<ChatReportReasonFake> for ChatReportReasonFake {
+  fn as_ref(&self) -> &ChatReportReasonFake { self }
+}
+
+impl AsRef<ChatReportReasonFake> for RTDChatReportReasonFakeBuilder {
+  fn as_ref(&self) -> &ChatReportReasonFake { &self.inner }
+}
+
+
+
+
+
+
+
 /// The chat contains pornographic messages
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
 pub struct ChatReportReasonPornography {
