@@ -124,6 +124,8 @@ pub struct ReplyMarkupForceReply {
   extra: Option<String>,
   /// True, if a forced reply must automatically be shown to the current user. For outgoing messages, specify true to show the forced reply only for the mentioned users and for the target user of a reply
   is_personal: bool,
+  /// If non-empty, the placeholder to be shown in the input field when the reply is active; 0-64 characters
+  input_field_placeholder: String,
   
 }
 
@@ -149,6 +151,8 @@ impl ReplyMarkupForceReply {
 
   pub fn is_personal(&self) -> bool { self.is_personal }
 
+  pub fn input_field_placeholder(&self) -> &String { &self.input_field_placeholder }
+
 }
 
 #[doc(hidden)]
@@ -165,6 +169,12 @@ impl RTDReplyMarkupForceReplyBuilder {
     self
   }
 
+   
+  pub fn input_field_placeholder<T: AsRef<str>>(&mut self, input_field_placeholder: T) -> &mut Self {
+    self.inner.input_field_placeholder = input_field_placeholder.as_ref().to_string();
+    self
+  }
+
 }
 
 impl AsRef<ReplyMarkupForceReply> for ReplyMarkupForceReply {
@@ -334,6 +344,8 @@ pub struct ReplyMarkupShowKeyboard {
   one_time: bool,
   /// True, if the keyboard must automatically be shown to the current user. For outgoing messages, specify true to show the keyboard only for the mentioned users and for the target user of a reply
   is_personal: bool,
+  /// If non-empty, the placeholder to be shown in the input field when the keyboard is active; 0-64 characters
+  input_field_placeholder: String,
   
 }
 
@@ -365,6 +377,8 @@ impl ReplyMarkupShowKeyboard {
 
   pub fn is_personal(&self) -> bool { self.is_personal }
 
+  pub fn input_field_placeholder(&self) -> &String { &self.input_field_placeholder }
+
 }
 
 #[doc(hidden)]
@@ -399,6 +413,12 @@ impl RTDReplyMarkupShowKeyboardBuilder {
     self
   }
 
+   
+  pub fn input_field_placeholder<T: AsRef<str>>(&mut self, input_field_placeholder: T) -> &mut Self {
+    self.inner.input_field_placeholder = input_field_placeholder.as_ref().to_string();
+    self
+  }
+
 }
 
 impl AsRef<ReplyMarkupShowKeyboard> for ReplyMarkupShowKeyboard {
